@@ -76,7 +76,7 @@ class CollectionCloner:
 
         des_db = des_client[self.des_db_name]
         
-        self.start_cloning()
+        self.start_cloning(src_db, des_db)
     
     def clone_local_to_remote(self):
         if self.src_db_name == '':
@@ -120,7 +120,7 @@ class CollectionCloner:
         
         des_db = des_client[self.des_db_name]
         
-        self.start_cloning()
+        self.start_cloning(src_db, des_db)
         
     def clone_remote_to_local(self):
         if self.src_db_name == '':
@@ -159,7 +159,7 @@ class CollectionCloner:
         des_client = pymongo.MongoClient('localhost')
         des_db = des_client[self.des_db_name]
         
-        self.start_cloning()
+        self.start_cloning(src_db, des_db)
         
     def clone_remote_to_remote(self):
         if self.src_db_name == '':
@@ -218,7 +218,7 @@ class CollectionCloner:
 
         des_db = des_client[self.des_db_name]
         
-        self.start_cloning()
+        self.start_cloning(src_db, des_db)
 
     # Cloning database
     def start_cloning(self, src_db, des_db):
